# Credits

## Core Contributions

- Dushyant M. Chaudhari ([@dushyant-fire](https://github.com/dushyant-fire)): Conceptualization, Methodology, front-end and back-end development/coding, Packaging, Documentation. 
- Anvii Mishra ([@anviimishra](https://github.com/anviimishra)): front-end development/coding for PyQT and Dashboard.

# Acknowledgement

The contributors are grateful to the [Fire Safety Research Institute](https://fsri.org/?utm_source=sphinx-documentation&utm_medium=direct&utm_campaign=FIREpyDAQ-public-launch), part of [UL Research Institute](https://ul.org/?utm_source=sphinx-documentation&utm_medium=direct&utm_campaign=FIREpyDAQ-public-launch), for supporting the development of this package.
